CSIP - Optimization Sensitivity and Uncertainty (COSU) Analysis Library 

This library provides a simple, yet powerful API for calibrating CSIP models. 
It supports:

* Particle Swarm Optimization for CSIP Services
* Stepwise Calibration (Rounds/Steps approach)
* Parallel Particle evaluation 

(requires Python 3.6)
